@@ -84,7 +84,7 @@ class ConceptParametizer(Parametizer):
 
     sort = StrParam()
     order = StrParam('asc')
-    published = BoolParam()
+    unpublished = BoolParam(False)
     embed = BoolParam(False)
     brief = BoolParam(False)
     query = StrParam()
@@ -208,19 +208,14 @@ class ConceptsResource(ConceptBase):
     def get(self, request, pk=None):
         params = self.get_params(request)
 
+        order = ['-category__order' if params['order'] == 'desc'
+                 else 'category__order']
+
         queryset = self.get_queryset(request)
 
         # For privileged users, check if any filters are applied, otherwise
         # only allow for published objects.
-        if can_change_concept(request.user):
-            filters = {}
-
-            if params['published'] is not None:
-                filters['published'] = params['published']
-
-            if filters:
-                queryset = queryset.filter(**filters)
-        else:
+        if not can_change_concept(request.user) or not params['unpublished']:
             queryset = queryset.published()
 
         # If Haystack is installed, perform the search
@@ -234,8 +229,12 @@ class ConceptsResource(ConceptBase):
             objects = (x.object for x in results)
         else:
             if params['sort'] == 'name':
-                order = '-name' if params['order'] == 'desc' else 'name'
-                queryset = queryset.order_by(order)
+                order.append('-name' if params['order'] == 'desc'
+                             else 'name')
+
+            # We need to order before a possible slice is taken because
+            # querysets cannot be ordered post-slice.
+            queryset = queryset.order_by(*order)
 
             if params['limit']:
                 queryset = queryset[:params['limit']]
